package com.qmth.teachcloud.mark.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.Update;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.qmth.teachcloud.common.enums.mark.MarkMode;
import com.qmth.teachcloud.mark.entity.MarkUserPaper;
import com.qmth.teachcloud.mark.enums.QuestionModel;
import com.qmth.teachcloud.mark.mapper.MarkUserPaperMapper;
import com.qmth.teachcloud.mark.service.MarkUserPaperService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 试卷评卷员设置 服务实现类
 * </p>
 *
 * @author xf
 * @since 2025-02-21
 */
@Service
public class MarkUserPaperServiceImpl extends ServiceImpl<MarkUserPaperMapper, MarkUserPaper> implements MarkUserPaperService {

    @Override
    public List<MarkUserPaper> listByExamIdAndPaperNumberAndUserId(Long examId, String paperNumber, Long userId) {
        QueryWrapper<MarkUserPaper> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(MarkUserPaper::getExamId, examId)
                .eq(MarkUserPaper::getPaperNumber, paperNumber)
                .eq(userId != null, MarkUserPaper::getUserId, userId);
        return this.list(queryWrapper);
    }

    public MarkUserPaper getByExamIdAndPaperNumberAndUserId(Long examId, String paperNumber, Long userId) {
        QueryWrapper<MarkUserPaper> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(MarkUserPaper::getExamId, examId)
                .eq(MarkUserPaper::getPaperNumber, paperNumber)
                .eq(MarkUserPaper::getUserId, userId);
        return this.getOne(queryWrapper);
    }

    @Override
    public void update(Long examId, String paperNumber, Long userId, MarkMode mode, QuestionModel questionModel, Long markedQuestionId) {
        MarkUserPaper markUserPaper = this.getByExamIdAndPaperNumberAndUserId(examId, paperNumber, userId);
        if (markUserPaper == null) {
            markUserPaper = new MarkUserPaper(examId, paperNumber, userId);
            markUserPaper.setMode(mode);
            markUserPaper.setQuestionModel(questionModel);
        } else {
            markUserPaper.setMode(mode);
            if (questionModel != null) {
                markUserPaper.setQuestionModel(questionModel);
            }
        }
        this.saveOrUpdate(markUserPaper);
    }
}
